Welcome to QAlgebra's documentation!
====================================

.. image:: https://img.shields.io/badge/github-mabuchilab/qalgebra-blue.svg
   :alt: Source code on Github
   :target: https://github.com/mabuchilab/qalgebra
.. image:: https://img.shields.io/pypi/v/qalgebra.svg
   :alt: QAlgebra on the Python Package Index
   :target: https://pypi.python.org/pypi/qalgebra

.. image:: https://img.shields.io/travis/mabuchilab/qalgebra.svg
   :alt: Travis Continuous Integration
   :target: https://travis-ci.org/mabuchilab/qalgebra
.. image:: https://img.shields.io/badge/appveyor-no%20id-red.svg
   :alt: AppVeyor Continuous Integration
   :target: https://ci.appveyor.com/project/mabuchilab/qalgebra
.. image:: https://img.shields.io/coveralls/github/mabuchilab/qalgebra/develop.svg
   :alt: Coveralls
   :target: https://coveralls.io/github/mabuchilab/qalgebra?branch=develop
.. image:: https://readthedocs.org/projects/qalgebra/badge/?version=latest
   :alt: Documentation Status
   :target: https://qalgebra.readthedocs.io/en/latest/?badge=latest
.. image:: https://img.shields.io/badge/License-MIT-green.svg
   :alt: MIT License
   :target: https://opensource.org/licenses/MIT

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   contributing
   authors
   history
   tutorial.ipynb


API
===

.. toctree::
   :maxdepth: 1

   API of the QAlgebra package <API/qalgebra>

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
